<?php

namespace Drupal\ai_webform_sentiment\Commands;

use Drupal\ai_webform_sentiment\SentimentProcessor;
use Drush\Commands\DrushCommands;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Drush commands for AI Webform Sentiment.
 */
class SentimentCommands extends DrushCommands {

  /**
   * The sentiment processor service.
   *
   * @var \Drupal\ai_webform_sentiment\SentimentProcessor
   */
  protected $sentimentProcessor;

  /**
   * Constructs a new SentimentCommands object.
   *
   * @param \Drupal\ai_webform_sentiment\SentimentProcessor $sentiment_processor
   *   The sentiment processor service.
   */
  public function __construct(SentimentProcessor $sentiment_processor) {
    $this->sentimentProcessor = $sentiment_processor;
    parent::__construct();
  }

  /**
   * Process sentiment analysis queue items.
   *
   * @command ai_webform_sentiment:process-queue
   * @aliases aisq
   * @usage ai_webform_sentiment:process-queue
   *   Process all pending sentiment analysis queue items.
   */
  public function processQueue() {
    $this->output()->writeln('Processing sentiment analysis queue...');
    
    $count = $this->sentimentProcessor->processQueue();
    
    $this->output()->writeln("Processed {$count} sentiment analysis items.");
  }

}